==> ScriptDeploy-0.1.tar: ScriptDeploy/action.edittemplate.php <==
<?php
#-------------------------------------------------------------------------
# Module: ScriptDeploy - Minify and deployment of JS CSS and HTML 
# Mod designed by jeremyBass (jeremyBass@cableone.net)
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/Cars/
#-------------------------------------------------------------------------
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#-------------------------------------------------------------------------

if(!$gCms) exit();


if(!$this->CheckPermission('Modify Templates')){
    // todo, permissions message here
    return;
}


$ModifedDateArray=array(
		'Buy Now'=>'_xclick',
		'Donate'=>'_donations',
		'Subscribe'=>'_xclick-subscriptions',
		'Buy Gift Certificate'=>'_oe-gift-certificate'
);

// handle errors.
if(isset($params['errors'])){
    echo $this->ShowErrors($params['errors']);
}

$params['origaction'] = $params['action'];
$contents = "";
    $this->smarty->assign('formstart',
			    $this->CreateFormStart ($id, 'save_Script_Setup',$returnid,'post','',
						    false, '', $params));
if($params['mode']=='add'){
    $this->smarty->assign('formstart',
			    $this->CreateFormStart ($id, 'save_Script_Setup',$returnid,'post','',false, '', $params));
    $this->smarty->assign('templatename',
			  $this->CreateInputText( $id, 'template', "", 40 ));
    $this->smarty->assign('hidden',
			  $this->CreateInputHidden($id, 'mode', $params['mode'] ));
    if( isset($params['defaulttemplatepref']) && $params['defaulttemplatepref'] != '' ){
		$contents = $this->GetPreference($params['defaulttemplatepref']);
     }
  }else{

	extract($this->TieAScript('select',$params['ScriptSet']));

//	$this->FireDebug('message','$Minify : '.$Minify);//<<<<------Fire PHP message	
//	$this->FireDebug('message','$Minify : '.$Minify);//<<<<------Fire PHP message	
//	$this->FireDebug('message','$maxAge : '.$maxAge);//<<<<------Fire PHP message	
//	$this->FireDebug('message','$CreationDate : '.$CreationDate);//<<<<------Fire PHP message	
//	$this->FireDebug('message','$ModifedDate : '.$ModifedDate);//<<<<------Fire PHP message	
//	$this->FireDebug('message','$pathOption : '.$pathOption);//<<<<------Fire PHP message	
//	$this->FireDebug('message','$ScriptSet : '.$ScriptSet);//<<<<------Fire PHP message	
//	$this->FireDebug('message','$ScriptID : '.$ScriptID);//<<<<------Fire PHP message	
//	$this->FireDebug('message','$ScriptID : '.$ScriptIs);//<<<<------Fire PHP message	


	$this->smarty->assign('ScriptSet_input',
			  $this->CreateInputText( $id, 'ScriptSet_input', $ScriptSet, 40, 255 ));
    $this->smarty->assign('Minify_input',
			 $this->CreateInputRadioGroup ($id, 'Minify_input', array('No'=>'0','Yes'=>'1'), $Minify,'','&nbsp;&nbsp;&nbsp;')); 
    $this->smarty->assign('maxAge_input',
			  $this->CreateInputText( $id, 'maxAge_input', $maxAge, 40 )); 		
    $this->smarty->assign('pathOption_input',
			  $this->CreateInputText( $id, 'pathOption_input', $pathOption, 40 ));  
    $this->smarty->assign('ScriptIs_input', $this->CreateTextArea(0,$id, $ScriptIs, 'ScriptIs_input',  ''));
    $this->smarty->assign('scriptType_input',
			 $this->CreateInputRadioGroup ($id, 'scriptType_input', array('JS'=>'JS','CSS'=>'CSS'), $scriptType,'','&nbsp;&nbsp;&nbsp;')); 	
		

   }

//$this->smarty->assign('title',cms_html_entity_decode($params['title']));
if( $params['mode'] == 'add' ){
  
    $this->smarty->assign('ScriptSet_input',
			  $this->CreateInputText( $id, 'ScriptSet_input', "", 40, 255, '' ));
    $this->smarty->assign('Minify_input',
			  $this->CreateInputRadioGroup ($id, 'Minify_input', array('No'=>'0','Yes'=>'1'), '0','','&nbsp;&nbsp;&nbsp;')); 
    $this->smarty->assign('maxAge_input',
			  $this->CreateInputText( $id, 'maxAge_input', "", 40 )); 		
	$this->smarty->assign('pathOption_input',
			  $this->CreateInputText( $id, 'pathOption_input', "", 40 ));  
    $this->smarty->assign('ScriptIs_input', $this->CreateTextArea (0, $id, '', 'ScriptIs_input', '','','','','80','20')); 
    $this->smarty->assign('scriptType_input',
			 $this->CreateInputRadioGroup ($id, 'scriptType_input', array('JS'=>'JS','CSS'=>'CSS'), 'JS','','&nbsp;&nbsp;&nbsp;')); 		
  
		      $this->smarty->assign('hiddenMode',
			  $this->CreateInputHidden($id, 'mode', $params['mode'] ));  

}

$this->FireDebug('message',$params['mode']);//<<<<------Fire PHP message
	  	  		  $this->smarty->assign('hiddenMode',
			$this->CreateInputHidden($id, 'mode', $params['mode'] )
			//.$this->CreateInputHidden($id, 'was', $params['VINV'] )
			);
		
$this->smarty->assign('smartyHow_label', $this->Lang('smartyHow')); 
	
$this->smarty->assign('scriptType_label', $this->Lang('scriptType_label')); 
$this->smarty->assign('ScriptSet_label', $this->Lang('ScriptSet_label')); 
$this->smarty->assign('Minify_label', $this->Lang('Minify_label')); 
$this->smarty->assign('maxAge_label', $this->Lang('maxAge_label'));			  
$this->smarty->assign('pathOption_label', $this->Lang('pathOption_label')); 
$this->smarty->assign('ScriptIs_label', $this->Lang('ScriptIs_label'));

$this->smarty->assign('form_cancel', '<input type="button" value="'.$this->Lang('form_cancel').'" onclick="javascript:window.history.go(-1)" />');	  
$this->smarty->assign('prompt_templatename',$this->Lang('prompt_templatename'));
$this->smarty->assign('prompt_template',$this->Lang('prompt_template'));
$this->smarty->assign('template',
		      $this->CreateSyntaxArea ($id, $contents, 'templatecontent'));
$this->smarty->assign('submit',$this->CreateInputSubmit ($id, 'submitbutton',
							 $this->Lang ('submit')));
$this->smarty->assign('cancel',$this->CreateInputSubmit ($id, 'cancel', 
							 $this->Lang ('cancel')));
$this->smarty->assign('formend',$this->CreateFormEnd());



echo $this->ProcessTemplate('edittemplate.tpl');

?>

==> ScriptDeploy-0.3.tar: ScriptDeploy/action.edittemplate.php <==
<?php
#-------------------------------------------------------------------------
# Module: ScriptDeploy - Minify and deployment of JS CSS and HTML 
# Mod designed by jeremyBass (jeremyBass@cableone.net)
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/Cars/
#-------------------------------------------------------------------------
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#-------------------------------------------------------------------------

if(!$gCms) exit();


if(!$this->CheckPermission('Modify Templates')){
    // todo, permissions message here
    return;
}
echo '<script type="text/javascript">
load = function() {
    load.getScript("http://ajax.microsoft.com/ajax/jQuery/jquery-1.3.2.min.js");
    // do stuff when jQuery finishes loading.
    load.tryReady(0);
}
load.getScript = function(filename) {
    var fileref = document.createElement("script")
    fileref.setAttribute("type","text/javascript")
    fileref.setAttribute("src", filename)
    if (typeof fileref!="undefined")
        document.getElementsByTagName("head")[0].appendChild(fileref)
}
load.tryReady = function(time_elapsed) {
    /* Continually polls for jQuery library. */
    if (typeof $ == "undefined") {
        if (time_elapsed <= 5000) {
            setTimeout("load.tryReady(" + (time_elapsed + 200) + ")", 200);
        } else {
            alert("Timed out while loading jQuery.")
        }
    }
}
if (typeof(window.jQuery)=="undefined"){
		load();   
}
	
	
</script>

<link media="screen" href="../modules/ScriptDeploy/CSS/MasterCSS.css" type="text/css" rel="stylesheet" />
<script type="text/javascript" src="http://cdn.jquerytools.org/1.1.2/tiny/jquery.tools.min.js"></script>
<script src="http://ajax.microsoft.com/ajax/jquery.validate/1.6/jquery.validate.min.js" type="text/javascript"></script>
<script type="text/javascript" src="../modules/ScriptDeploy/includes/ME_1.00.00.js"></script>


<div id="demotip"><img class="progress" src="../modules/ScriptDeploy/images/ajax-loader.gif" alt=""/></div>

';

$MediaTypeArray=array(
		'all'=>'all',
		'aural'=>'aural',
		'braille'=>'braille',
		'handheld'=>'handheld',
		'print'=>'print',
		'embossed'=>'embossed',
		'projection'=>'projection',
		'screen'=>'screen',
		'tty'=>'tty',
		'tv'=>'tv'
);

// handle errors.
if(isset($params['errors'])){
    echo $this->ShowErrors($params['errors']);
}

$params['origaction'] = $params['action'];
$contents = "";
    $this->smarty->assign('formstart',
			    $this->CreateFormStart ($id, 'save_Script_Setup',$returnid,'post','',
						    false, '', $params));
if($params['mode']=='add'){
    $this->smarty->assign('formstart',
			    $this->CreateFormStart ($id, 'save_Script_Setup',$returnid,'post','',false, '', $params));
    $this->smarty->assign('templatename',
			  $this->CreateInputText( $id, 'template', "", 40 ));
    $this->smarty->assign('hidden',
			  $this->CreateInputHidden($id, 'mode', $params['mode'] ));
    if( isset($params['defaulttemplatepref']) && $params['defaulttemplatepref'] != '' ){
		$contents = $this->GetPreference($params['defaulttemplatepref']);
     }
  }else{

	extract($this->TieAScript('select',$params['ScriptSet']));

//	$this->FireDebug('message','$Minify : '.$Minify);//<<<<------Fire PHP message	
//	$this->FireDebug('message','$Minify : '.$Minify);//<<<<------Fire PHP message	
//	$this->FireDebug('message','$maxAge : '.$maxAge);//<<<<------Fire PHP message	
//	$this->FireDebug('message','$CreationDate : '.$CreationDate);//<<<<------Fire PHP message	
//	$this->FireDebug('message','$ModifedDate : '.$ModifedDate);//<<<<------Fire PHP message	
//	$this->FireDebug('message','$pathOption : '.$pathOption);//<<<<------Fire PHP message	
//	$this->FireDebug('message','$ScriptSet : '.$ScriptSet);//<<<<------Fire PHP message	
//	$this->FireDebug('message','$ScriptID : '.$ScriptID);//<<<<------Fire PHP message	
//	$this->FireDebug('message','$ScriptID : '.$ScriptIs);//<<<<------Fire PHP message	

    $this->smarty->assign('MediaType_input',
			  $this->CreateInputDropdown($id, 'MediaType_input', $MediaTypeArray, '', $MediaType));
	$this->smarty->assign('ScriptSet_input',
			  $this->CreateInputText( $id, 'ScriptSet_input', $ScriptSet, 40, 255 ));
    $this->smarty->assign('Minify_input',
			 $this->CreateInputRadioGroup ($id, 'Minify_input', array('No'=>'0','Yes'=>'1'), $Minify,'','&nbsp;&nbsp;&nbsp;')); 
    $this->smarty->assign('maxAge_input',
			  $this->CreateInputText( $id, 'maxAge_input', $maxAge, 40 )); 		
    $this->smarty->assign('pathOption_input',
			  $this->CreateInputText( $id, 'pathOption_input', $pathOption, 40 ));  
	$this->smarty->assign('notes_input', $this->CreateTextArea(0,$id, $notes, 'notes_input','','','','','',10));
    $this->smarty->assign('ScriptIs_input', $this->CreateTextArea(0,$id, $ScriptIs, 'ScriptIs_input', '','SIA','','','80','20')); 
    $this->smarty->assign('scriptType_input',
			 $this->CreateInputRadioGroup ($id, 'scriptType_input', array('JS'=>'JS','CSS'=>'CSS'), $scriptType,'','&nbsp;&nbsp;&nbsp;')); 	
   }

//$this->smarty->assign('title',cms_html_entity_decode($params['title']));
if( $params['mode'] == 'add' ){
	$this->smarty->assign('MediaType_input',
			  $this->CreateInputDropdown($id, 'MediaType_input', $MediaTypeArray, '', '')); 
    $this->smarty->assign('ScriptSet_input',
			  $this->CreateInputText( $id, 'ScriptSet_input', "", 40, 255, '' ));
    $this->smarty->assign('Minify_input',
			  $this->CreateInputRadioGroup ($id, 'Minify_input', array('No'=>'0','Yes'=>'1'), '0','','&nbsp;&nbsp;&nbsp;')); 
    $this->smarty->assign('maxAge_input',
			  $this->CreateInputText( $id, 'maxAge_input', "", 40 )); 		
	$this->smarty->assign('pathOption_input',
			  $this->CreateInputText( $id, 'pathOption_input', "", 40 ));
	$this->smarty->assign('notes_input', $this->CreateTextArea (0, $id, '', 'notes_input','','','','','',10));
    $this->smarty->assign('ScriptIs_input', $this->CreateTextArea (0, $id, '', 'ScriptIs_input', '','SIA','','','80','20')); 
    $this->smarty->assign('scriptType_input',
			 $this->CreateInputRadioGroup($id, 'scriptType_input', array('JS'=>'JS','CSS'=>'CSS'), 'JS','','&nbsp;&nbsp;&nbsp;')); 		
    $this->smarty->assign('CSSmedia_input',
			 $this->CreateInputRadioGroup($id, 'CSSmedia_input', array('JS'=>'JS','CSS'=>'CSS'), 'JS','','&nbsp;&nbsp;&nbsp;')); 			      $this->smarty->assign('hiddenMode',
			  $this->CreateInputHidden($id, 'mode', $params['mode'] ));  

}

$this->FireDebug('message',$params['mode']);//<<<<------Fire PHP message
	  	  		  $this->smarty->assign('hiddenMode',
			$this->CreateInputHidden($id, 'mode', $params['mode'] )
			//.$this->CreateInputHidden($id, 'was', $params['VINV'] )
			);
		
$this->smarty->assign('smartyHow_label', $this->Lang('smartyHow')); 
$this->smarty->assign('MediaType_label', $this->Lang('MediaType_label')); 	
$this->smarty->assign('scriptType_label', $this->Lang('scriptType_label')); 
$this->smarty->assign('ScriptSet_label', $this->Lang('ScriptSet_label')); 
$this->smarty->assign('Minify_label', $this->Lang('Minify_label')); 
$this->smarty->assign('maxAge_label', $this->Lang('maxAge_label'));			  
$this->smarty->assign('pathOption_label', $this->Lang('pathOption_label')); 
$this->smarty->assign('ScriptIs_label', $this->Lang('ScriptIs_label'));
$this->smarty->assign('notes_label', $this->Lang('notes_label'));

$this->smarty->assign('form_cancel', '<input type="button" value="'.$this->Lang('form_cancel').'" onclick="javascript:window.history.go(-1)" />');	  
$this->smarty->assign('prompt_templatename',$this->Lang('prompt_templatename'));
$this->smarty->assign('prompt_template',$this->Lang('prompt_template'));
$this->smarty->assign('template',
		      $this->CreateSyntaxArea ($id, $contents, 'templatecontent'));
$this->smarty->assign('submit',$this->CreateInputSubmit ($id, 'submitbutton',
							 $this->Lang ('submit')));
$this->smarty->assign('cancel',$this->CreateInputSubmit ($id, 'cancel', 
							 $this->Lang ('cancel')));
$this->smarty->assign('formend',$this->CreateFormEnd());



echo $this->ProcessTemplate('edittemplate.tpl');

?>
